@@ -1,7 +1,5 @@
 # flake8: noqa
 
-import pkg_resources
-
 from .cached_download import cached_download
 from .cached_download import md5sum
 from .download import download
@@ -9,4 +7,4 @@ from .download_folder import download_folder
 from .extractall import extractall
 
 __author__ = "Kentaro Wada <www.kentaro.wada@gmail.com>"
-__version__ = pkg_resources.get_distribution("gdown").version
+__version__ = "4.5.2"
